# Easy access to Meteo-France API

It currently covers downloading of:

- Hourly climatotlogical data for one station
- BRA (Bulletin d'Estimation du risque d'avalanche)

## 0. Get an account on Meteo-France API

Have a look to https://portail-api.meteofrance.fr/web/fr/faq !

## 1.Install
```bash
pip install git+https://git.vln-glr.fr/leo.viallon/mfapi.git
```

## 2.Configuration
Create a file containing;

```ini
[DEFAULT]
application_id = the-application-id-you-got-on-mf-api-website
```

L'application id se trouve sur le site API de Météo-France en cliquant sur user, Mes API, puis Générer Token. Il vous sera affiché une commande curl de la forme suivante:
``curl -k -X POST https://portail-api.meteofrance.fr/token -d "grant_type=client_credentials" -H "Authorization: Basic APPLICATION_ID"``

## 3.Examples

### 3.1 The BRA

```python
import mfapi
c = mfapi.MFAPIClient(config_file='path_to_your_config_file')
c.get_bra(23, format='pdf')  # 23 is the massif code of Mercantour (Alps : 1-23, Pyrenees: 64-74, Corsica: 40-41)
```
 The file is stored as `BRA_23.pdf`.

You can also get XML format (and images needed to render with):

```python
c.get_bra(23, format='xml', images=True)
 ```

### 3.2 Climatological data

```python
import mfapi
import datetime
c = mfapi.MFAPIClient(config_file='path_to_your_config_file')
c.get_clim_h('65413400', begin=datetime.datetime(2024, 9, 1), end=datetime.datetime(2024, 12, 1))  # You first have to know the Station id
```

The data is stored under csv format.

# Bibliothèque d'accès facile aux APIs de Météo-France

Cette bibliothèque couvre actuellement les API suivantes :

- Donnée shoraires climatologiques
- BRA (Bulletin d'Estimation du risque d'avalanche)

L'usage de cette libraiire suppose que vous vous soyez créé un compte sur le portail API de Météo-France et que vous ayez souscrit aux API que vous souhaitez utiliser. Vous devez également disposer d'un token OAuth2 (application ID). Pour plus de détails, consultez https://portail-api.meteofrance.fr/web/fr/faq

## 1. Installation du package

```bash
pip install git+https://git.vln-glr.fr/leo.viallon/mfapi.git
```

## 2. Configuration du package

Vous devez créer un fichier contenant

```ini
[DEFAULT]
application_id = the-application-id-you-got-on-mf-api-website
```

L'application id se trouve sur le site API de Météo-France en cliquant sur user, Mes API, puis Générer Token. Il vous sera affiché une commande curl de la forme suivante:
``curl -k -X POST https://portail-api.meteofrance.fr/token -d "grant_type=client_credentials" -H "Authorization: Basic APPLICATION_ID"``

## 3.Examples

### 3.1 Le BRA

```python
import mfapi
c = mfapi.MFAPIClient(config_file='path_to_your_config_file')
c.get_bra(23, format='pdf')  # 23 is the massif code of Mercantour (Alps : 1-23, Pyrenees: 64-74, Corsica: 40-41)
```

Le fichier PDF contenant le BRA est stocké sous le nom `BRA_23.pdf` dans le dossier courant. Vous pouvez également obtenir le BRA au format XML (ainsi que le simages nécessaires pour le rendu avec:

```python
c.get_bra(23, format='xml', images=True)
 ```

### 3.2 Données climatologiques horaires

```python
import mfapi
import datetime
c = mfapi.MFAPIClient(config_file='path_to_your_config_file')
c.get_clim_h('65413400', begin=datetime.datetime(2024, 9, 1), end=datetime.datetime(2024, 12, 1))  # You first have to know the Station id
```

Les données sont stockées dans le dossier courant au format csv.
